import * as log from './log'
import * as mqtt from './mqttdispatcher'
import * as callchain from './callchain'
import * as fs from 'fs'
import * as cmdargs from 'command-line-args'

import * as EspThermToJson from './espthermtojson'
import * as MongoSave from './mongosave'
import * as MissingEventDetector from './missingeventdetector'


const OPTION_DEFINITIONS = [
    { name: 'verbose', alias: 'v', type: Boolean },
    { name: 'config', alias: 'c', type: String, defaultValue: '~/mqttDispatcher.conf' }
];
const OPTIONS = cmdargs(OPTION_DEFINITIONS)
const CONFIG = JSON.parse(fs.readFileSync(OPTIONS.config, "utf8"))




log.info("Dispatcher starting")

let dispatcher = new mqtt.MqttDispatcher(CONFIG.brokerUrl, 
    CONFIG.brokerUser, CONFIG.brokerPass, CONFIG.brokerCa)

const ESP_THERM_TOPIC : string = 'IoT/espThermometer2/#'
dispatcher.register(ESP_THERM_TOPIC, 'toJson', EspThermToJson.espThermToJson)

let missingeventdetector : MissingEventDetector.MissingEventDetector = 
    new MissingEventDetector.MissingEventDetector()
dispatcher.register(ESP_THERM_TOPIC, 'MissingEventDetector', missingeventdetector)

// let mongo : MongoSave.MongoSave = new MongoSave.MongoSave(CONFIG.mongoDbUrl)
// dispatcher.register(ESP_THERM_TOPIC, 'MongoSave', mongo);


dispatcher.exec()
log.info("Dispatcher running")






